summaryrefslogtreecommitdiff
path: root/Kernel/kprintf.cpp
diff options
context:
space:
mode:
authorLiav A <liavalb@gmail.com>2021-04-24 17:50:35 +0300
committerAndreas Kling <kling@serenityos.org>2021-05-16 19:58:33 +0200
commit8f2ddde4cb0cba281d9144123bbdd92db9233654 (patch)
tree9c3c9c0967676385349f8b14439f10e0031ba2c9 /Kernel/kprintf.cpp
parent0669dd82e2bc19c007690c6723cb4230ac4a55f9 (diff)
downloadserenity-8f2ddde4cb0cba281d9144123bbdd92db9233654.zip
Kernel: Rename Console => ConsoleDevice
This change will help to distinguish between the console device and the Console abstraction layer in the Graphics subsystem later.
Diffstat (limited to 'Kernel/kprintf.cpp')
-rw-r--r--Kernel/kprintf.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Kernel/kprintf.cpp b/Kernel/kprintf.cpp
index bb1d899841..fb3401e0eb 100644
--- a/Kernel/kprintf.cpp
+++ b/Kernel/kprintf.cpp
@@ -6,7 +6,7 @@
#include <AK/PrintfImplementation.h>
#include <AK/Types.h>
-#include <Kernel/Console.h>
+#include <Kernel/ConsoleDevice.h>
#include <Kernel/IO.h>
#include <Kernel/Process.h>
#include <Kernel/SpinLock.h>
@@ -65,10 +65,10 @@ static void console_out(char ch)
if (serial_debug)
serial_putch(ch);
- // It would be bad to reach the assert in Console()::the() and do a stack overflow
+ // It would be bad to reach the assert in ConsoleDevice()::the() and do a stack overflow
- if (Console::is_initialized()) {
- Console::the().put_char(ch);
+ if (ConsoleDevice::is_initialized()) {
+ ConsoleDevice::the().put_char(ch);
} else {
IO::out8(0xe9, ch);
}